Name:           fcl
Version:        0.5.0
Release:        2%{?dist}
Summary:        Flexible Collision Library


License:        BSD
URL:            https://github.com/flexible-collision-library/fcl
Source0:        https://github.com/flexible-collision-library/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# Add missing licensing information to FCL sources.
# https://github.com/flexible-collision-library/fcl/commit/d564e4fda6eb91450bf962311ba701481ac922d8.patch
Patch0:         %{name}-0.5.0-license.patch

BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  flann-devel
BuildRequires:  libccd-devel
BuildRequires:  octomap-devel
BuildRequires:  tinyxml-devel

%description
FCL is a library for performing three types of proximity queries on a pair
of geometric models composed of triangles.
* Collision detection: detecting whether the two models overlap, and
optionally, all of the triangles that overlap.
* Distance computation: computing the minimum distance between a pair
of models, i.e., the distance between the closest pair of points.
* Tolerance verification: determining whether two models are closer or
farther than a tolerance distance.
* Continuous collision detection: detecting whether the two moving models
overlap during the movement, and optionally, the time of contact.
* Contact information: for collision detection and continuous collision
detection, the contact information (including contact normals and contact
points) can be returned optionally.

%package devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -n %{name}-%{version} -p 1

# Remove spurious executable permissions
find . -type f -perm /111 -name "*.h" -print -exec chmod -x '{}' \;
find . -type f -perm /111 -name "*.cpp" -print -exec chmod -x '{}' \;

%build
mkdir -p build; cd build
%cmake ..
make %{?_smp_mflags}

%install
%make_install -C build

%check
export LD_LIBRARY_PATH=$RPM_BUILD_ROOT%{_libdir}
make -C build test ARGS="-V" || exit 0

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%license LICENSE
%doc README.md CHANGELOG.md
%{_libdir}/*.so.*

%files devel
%{_includedir}/fcl
%{_libdir}/pkgconfig/*.pc
%{_libdir}/cmake
%{_libdir}/*.so

%changelog
* Fri Oct 21 2016 Rich Mattes <rmattes@fedoraproject.org> - 0.5.0-2
- Add License and Changelog to package
- Use git tag instead of git commit for source URL

* Sun Aug 14 2016 Rich Mattes <rmattes@fedoraproject.org> - 0.5.0-1
- Update to release 0.5.0
- Remove upstreamed patches
- Add missing license information from upstream commit
- Remove spurious executable permissions from source files

* Thu Jan 07 2016 Rich Mattes <rmattes@fedoraproject.org> - 0.3.2-2
- Add patch to correct install dirs and library versioning

* Sun Mar 01 2015 Rich Mattes <rmattes@fedoraproject.org> - 0.3.2-1
- Update to release 0.3.2

* Sun Jun 01 2014 Rich Mattes <rmattes@fedoraproject.org> - 0.3.1-1
- Initial build (rhbz#1103555)
